phi = 22/7

def kali(*args):
    result = 1
    for i in args:
        result *= i
    print(result)
def tambah(*args):
    result = 0
    for i in args:
        result += i
    print(result)
def bagi(*args):
    if not args:
        print("No arguments provided. Division result undefined.")
        return None
    
    result = args[0]  
    for i in args[1:]:  
        result /= i
    print(result)
def akar(a):
    print(pow(a ,1/2))
def kurang(*args):
    result = 0
    for i in args:
        result -= i
    print(result)
def pangkat(a,b):
    z = pow(a,b)
    print(z)

# geometry


phi = 22/7

def luas_segitiga(a,t):
    result = 1/2 * a * t
    print(result)
def keliling_segitiga(a,b,c):
    print(a+b+c)
def luas_persegi_panjang(p,l):
    result = p * l 
    print(result)
def keliling_persegi_panjang(p,l):
    print(2 * (p+l))
def luas_persegi(a):
    print(a * a)
def keliling_persegi(s):
    print(4 * s)
def luas_jajar_genjang(a,t):
    print(a * t)
def keliling_jajar_genjang(a,b,c,d):
    print(a + b + c + d)
def luas_lingkaran(r):
    print(phi * r * r)
def keliling_lingkaran(r,d):
    print(2*phi*r)
def keliling_trapesium(a,b,c,d):
    print(a + b + c + d)
def luas_trapesium(a,b,t):
    print(1/2 * (a+b) * t)
def luas_layang(x,y):
    print(1/2*x*y)
def keliling_layang(a,b,c,d):
    print(a + b + c + d)
def luas_belah_ketupat(x,y):
    print(1/2 * x * y)
def keliling_belah_ketupat(a,b,c,d):
    print(a + b + c + d)

# other

from math import *

def terbesar(*args):
    max(args)
def terkecil(*args):
    min(args)
def nilai_cos(derajat):
    cos(derajat)
def nilai_sin(derajat):
    sin(derajat)
def nilai_tan(derajat):
    tan(derajat)


from setuptools import setup
setup(name='indomath',
      version='0.3.2',
      description='Sebuah progam matematika',
      author='VincentVe,Febrianto',
      author_email='sayuzvernando1@gmail.com',
      license='MIT',
      packages=['indomath']
)